@@ -27,8 +27,10 @@ RETCODE SQL_API SQLDummyOrdinal(void);
 
 #ifdef WIN32
 HINSTANCE NEAR s_hModule;		/* Saved module handle. */
-#ifdef	WIN_MULTITHREAD_SUPPORT
+#if defined(WIN_MULTITHREAD_SUPPORT)
 extern	CRITICAL_SECTION	qlog_cs, mylog_cs, conns_cs;
+#elif defined(POSIX_MULTITHREAD_SUPPORT)
+extern	pthread_mutex_t 	qlog_cs, mylog_cs, conns_cs;
 #endif /* WIN_MULTITHREAD_SUPPORT */
 
 /*	This is where the Driver Manager attaches to this Driver */
@@ -68,8 +70,8 @@ DllMain(HANDLE hInst, ULONG ul_reason_for_call, LPVOID lpReserved)
 
 		case DLL_PROCESS_DETACH:
 			DELETE_CONNS_CS;
+            DELETE_MYLOG_CS;
 			DELETE_QLOG_CS;
-			DELETE_MYLOG_CS;
 			WSACleanup();
 			return TRUE;
 
